% Center Pool drainage example
%**************************************************************
tic
clc
clear all; clc; close all
Kr=1; Kz=0.2; % hydraulic conductivity [m/day]
R=10; L=0.4; % polygon dimensions
H0=0.65;      	% initial water depth

E=[0 0.0005 0.002];		% ET in m/day
tdry1=E; tdry2=E;       % array for dry times
kappa=1.0; % mass transfer coefficient [day^-1]
Bi=kappa*L/sqrt(Kr*Kz)
RR=R/L*sqrt(Kz/Kr);
% roots and convergence
eps=10^-5; % tolerance of series convergence
N_lambda=2000; % number of roots to compute upfront 
        BiM=Bi*RR;     % modified Bi for using J, Beck's subroutine
        lambRR=feigR03(N_lambda,BiM);  % array  of lambda(n)*RR_j 
        lambda=lambRR/RR; % from modified to non-modified lambda(n) array 
% Computing Q
        Q=0;
            for n=1:N_lambda     
                term=2*tanh(lambda(n))/(lambda(n)*((lambda(n)/Bi)^2+1));
                Q=Q+term;
                 if abs(term/Q)<eps
                     break
                 end    
            end
% computing answers
Q, N_term=n
t_L=R^2/(2*Kr*L*Q);
t_Lr=round(t_L,0); Qr=round(Q,1);
time=linspace(0,100, 20);
tstar=time/t_L; 

f = figure('units', 'inches', 'position', [1 1 3.75 3]);

c = [0.0 0.0 0.99 1.0;      % color for line plots, h_w=0.45
     0.0 0.0 0.99 0.6;
     0.0 0.0 0.99 0.3];
 
h_w=0.45;     	% water level in trough
Estar=E*t_L/(H0-h_w);
for i=1:3
    Est_i=Estar(i);
Ht=h_w+(H0-h_w)*(exp(-tstar)-Est_i*(1-exp(-tstar))); % with Evaporation
y=0*time+h_w;
plot (time, Ht, 'color', c(i,:), 'linewidth', 1); hold on
plot (time, y, '-', 'color', [0 0 0.99]);
if (h_w-L)< Est_i*(H0-h_w) 
    tdry1(i)=t_L*log(1+(H0-L)./(L-h_w+Est_i*(H0-h_w)));
else
    tdry1(i)=999;
end
end

c2 = [0.0 0.6 0.0 1.0;      % color for line plots, h_w=0.35
      0.0 0.6 0.0 0.6;
      0.0 0.6 0.0 0.3];

h_w=0.35
Estar=E*t_L/(H0-h_w);
for i=1:3
    Est_i=Estar(i);
Ht=h_w+(H0-h_w)*(exp(-tstar)-Est_i*(1-exp(-tstar))); % with Evaporation
y=0*time+L; z=0*time+h_w;

tnew = 0:1:100;
Htnew = interp1(time, Ht, tnew);
ponded = Htnew >= 0.4;

plot(tnew(ponded), Htnew(ponded), 'color', c2(i,:), 'linewidth', 1); hold on
plot(tnew(~ponded), Htnew(~ponded), ':', 'color', c2(i,:), 'linewidth', 1);

stem(max(tnew(ponded)), 0.4, 'filled', 'color', c2(i,:), 'markersize', 3);

plot(time, z, '-', 'color', [0 0.6 0]);
plot(time, y, 'k-');
end
hold off
tdry2=t_L*log(1+(H0-L)./(L-h_w+E*t_L)); 

xlabel('time [days]', 'fontname', 'arial', 'fontsize', 8); 
ylabel('Center pool level \fontname{Times}\itH(t) \fontname{Arial}\rm[m]', 'fontname', 'arial', 'fontsize', 8);

text(1, 0.45-0.015, 'h_w=0.45m', 'fontname', 'arial', 'fontsize', 8, ...
    'fontangle', 'italic', 'color', [0 0 0.99]);
text(1, 0.4-0.012, 'L=0.4m', 'fontname', 'arial', 'fontsize', 8, ...
    'fontangle', 'italic', 'color', 'k');
text(1, 0.35-0.015, 'h_w=0.35m', 'fontname', 'arial', 'fontsize', 8, ...
    'fontangle', 'italic', 'color', [0 0.6 0]);

ylim([0.3 0.65]);

ax = gca;
ax.XAxis.FontName = 'arial';
ax.XAxis.FontSize = 8;
ax.YAxis.FontName = 'arial';
ax.YAxis.FontSize = 8;

tdry1, tdry2

hold on

% create legend
c3 = [c; c2];
linestyle = {'-' '-' '-' '-' '-' '-'};
labels = {'h_w=0.45, E=0'...
          'h_w=0.45, E=5e-4' ...
          'h_w=0.45, E=2e-3' ...
          'h_w=0.35, E=0'...
          'h_w=0.35, E=5e-4' ...
          'h_w=0.35, E=2e-3'};

for i = 1:6
    h(i) = plot([nan nan], [nan nan], 'linewidth', 1, 'color', c3(i,:), ...
        'linestyle', linestyle{i}, 'displayname', labels{i});
end

l = legend(h);
l.FontName = 'arial';
l.FontSize = 7.5;
l.Box = 'off';
l.Position = l.Position + [0.02 0.02 0 0];

toc
